#!/bin/bash

##################################
#Script to compute Delta A_1 term#
##################################

GMX="~/Travail/Simulations/gromacs-2018/gromacs/bin/gmx_d"

# Variable definitions
### N = number of configurations
### tstep = the time interval in ps between the stored configurations of the ideal gas run
###         (tstep=dt*nstxtcout, where dt corresponds to the time step used in the ideal gas run and
###         nstxtcout the frequency for saving configurations)
### T = temperature
### nmol = number of atoms
### ulattgrom = U_lattice energy (in GROMACS units)
N=10000
tstep=0.5
T=12.0
nmol=768                          # VB: for 768 atoms

# Read U_LJ energy from file "../2-U_LJ/U_LJ.dat"
read ulattgrom < ../2-U_LJ/U_LJ.dat

echo "-------------------------------"
echo "Using U_LJ_perfectcrystal = " $ulattgrom
echo "-------------------------------"

# Calculate LJ energies over the configurations of the simulation traj_comp.xtc
export GMX_MAXBACKUP=-1      #VB: we don't want backups
~/Travail/Simulations/gromacs-2018/gromacs/bin/gmx_d mdrun -s ../2-U_LJ/topol.tpr -rerun ../1-EinsteinCrystal/traj_comp.xtc

# Extract energies to file ener.edr and energy.xvg
echo "3 0" | ~/Travail/Simulations/gromacs-2018/gromacs/bin/gmx_d energy -b 30          # VB: energies have converged only at time 30 ps ! $tstep

tail --lines=+25  energy.xvg > energies.dat   #skip header of .xvg file

# ========= calculation of Delta A_1 =============

# Convert lattice energy from GROMACS units to k_BT units
ulatt=`echo $T $ulattgrom | awk '{print $2*1000/(8.314*$1)}'`
ulattnkt=`echo $T $ulattgrom $nmol | awk '{print $2*1000/($3*8.314*$1)}'`

echo ""
echo "--------------------------"
echo "U_latt (kT units) ----> " $ulatt
echo "U_latt (NkT units) ----> " $ulattnkt

# Convert the potential energy of each configuration (energies.dat) to k_BT units
# and compute the Delta A_1 term. 
awk -v temp=$T '{print $1,($2*1000)/(8.314*temp)}' energies.dat > kt_energies.dat
awk -v latt=$ulatt '{print $1,($2-latt)}' kt_energies.dat > u_sol-u_latt.dat
awk '{print $1,exp(-$2)}' u_sol-u_latt.dat > exp_u_sol-u_latt.dat
prod=`echo $OUTPUT | awk '{s+=$2}END{print s/NR}' exp_u_sol-u_latt.dat`

echo "av_exp(-beta(U_sol-U_latt)) ----> " $prod

logN=`echo $prod $nmol | awk '{print log($1)/$2}'`

echo "1/N ln[av_exp(-beta(U_sol-U_latt))] ----> " $logN

deltaA1=`echo $ulatt $nmol | awk -v aver=$logN '{print ($1/$2)-(aver)}'`

echo ""
echo "--------------------------"
echo ""
echo "DA_1/NkT ----> " $deltaA1

# Save the results to a file
echo "DA_1/NkT ----> " $deltaA1 >_result_deltaA1.txt

echo "--------------------------" >>_result_deltaA1.txt
echo "U_latt (kT units) ----> " $ulatt >>_result_deltaA1.txt
echo "U_latt (NkT units) ----> " $ulattnkt >>_result_deltaA1.txt
echo "av_exp(-beta(U_sol-U_latt)) ----> " $prod >>_result_deltaA1.txt
echo "1/N ln[av_exp(-beta(U_sol-U_latt))] ----> " $logN >>_result_deltaA1.txt