# This script computes the spring constants to be considered for the Gauss-Legendre integrations of eq.(_)
# The results are saved to file "landas.out"

import numpy as np
#import matplotlib.pyplot as plt
import pandas as pd

# Parameters
T = 12         # in Kelvin
kE = 448956    # Maximal spring constant in kJ.mol^{-1}.nm^{-2} 

# Bolztmann constant
# kB = 8.314462618 * 1e-3   in units of kJ.mol^{-1}.K^{-1}

R = 8.314462618
d = 10/(R*T)            # = 1e-2 / (kB * T) 
c = np.exp(3.5)

# Coefficients for the "normalized" Gauss-Legendre integration (interval [-1, 1])
n = 15
df = pd.read_table('GaussLegendre_n=15.csv', sep=',', header=3)
point_no = np.array([float(i) for i in range(1, n+1)])

# Sort according to ascending abscissas
df_sorted = df.sort_values('abscissas')

array = df_sorted.to_numpy()
weights = array[:, 0]
abscissas = array[:, 1]
#print(weights)
#print(abscissas)

# Change of variable: x = ln(λ * kE/2 * d + c)

# Boundaries of the integration domain
a = np.log(c)
b = np.log(kE/2 * d + c)

y = abscissas
kE_abscissas = 2 * 1/d * ( np.exp((a+b)/2 + y*(b-a)/2) - c )

# print("Spring constants :")
# print(kE_abscissas)
# print("Weights :")
# print(weights * (b-a)/2)

table = np.array((point_no, kE_abscissas, weights * (b-a)/2)).T

print("Results saved to file landas.dat")
np.savetxt('landas.dat', table, fmt='%.9g', delimiter='\t')

# header for the file:
# n \t k_E   \t Weight      (The unit of k_E is kJ.mol^{-1}.nm^{-2})