#!/bin/bash

##################################
#Script to compute Delta A_2 term#
##################################

# Variable definitions
### N = number of k' values
### nmol = number of atoms
### cexp = exp(c), where c=3.5 is a constant needed to integrate numerically the Eq.(39)
### of [C.Vega et al., J. Phys. Cond. Matt., 20, 153101 (2008)] (see also Ref.
### [Undertanding Molecular Simulation of D. Frenkel and B. Smit, second Edition, page 260]) 
N=15
T=12.          # <-- ADJUST THE TEMPERATURE
nmol=768
cexp=33.11545

# Remove old files
rm pesos.dat calcula.dat
rm -r ./director
rm energies.dat integral.dat
mkdir ./director

export GMX_MAXBACKUP=-1      #VB: we don't want backups

echo "========================="
echo " WARNING: don't forget to do first"
echo "1) Adjust the spring constant in file calc_GaussLegendre_xi_wi.py"
echo "2) python calc_GaussLegendre_xi_wi.py"
echo "========================="

echo "Started at :"
date

(for ((i=1; i<$N+1; i++)); do

echo "--------------------------"
echo "Running simulation " $i "/" $N
echo "--------------------------"

# Read the value of k' and the Gaussian quadrature weight
 read num landa w
 #echo $landa $w
 echo $w >> pesos.dat

 mkdir ./director/$landa

# Change the value of the spring constant on the topol.top file
 head -25 topol.orig > topol.top
 echo "   1    1    $landa  $landa  $landa ">> topol.top
 tail -9 topol.orig >> topol.top

# Execute GROMACS
 ~/Travail/Simulations/gromacs-2018/gromacs/bin/gmx_d grompp -maxwarn 1 -c ../1-EinsteinCrystal/conf.g96 -r ../1-EinsteinCrystal/restraint.g96 > grompp.log || exit -1
 ~/Travail/Simulations/gromacs-2018/gromacs/bin/gmx_d mdrun -c confout.g96 -ntmpi 4   || exit -1     # VB: limit number of threads because of a bug in GROMACS

# Compute the position restraint energy using the g_energy GROMACS's tool 
# Extract energies to file ener.edr and energy.xvg
echo "3 0" | ~/Travail/Simulations/gromacs-2018/gromacs/bin/gmx_d energy -b 2000 | cat > kk         # start at time step 2000
 tail -3 kk > kk2
 tail -1 kk2 > save

 read numkk kk3 ener kk4 kk5 kk6 kk7 < save
# Save the energy of the configuration in the energies.dat file
 echo $landa $ener >> energies.dat 

# Remove useless files
 rm energy.xvg

 mv confout.g96 topol.top topol.tpr ./director/$landa
 mv traj.* ./director/$landa
 mv ener.edr md.log mdout.mdp ./director/$landa
 rm state.cpt grompp.log kk kk2 save
 rm state*

done) < landas.dat

#Compute the mean square displacements from the position restraint energies.
awk -v temp=$T mol=$nmol'{print ($1/2.)*(10/(8.314*temp)),$2/($1/2.)*(100/mol)}' energies.dat > integral.dat
# $1 is the spring constant to be used in file topol.top  (unit: kJ.mol^{-1}.nm^{-2}) 
# $2 is the energy of the harmonic oscillators (unit: kJ.mol^{-1})
# In integral.dat:
#   - the first term is 1/2*kE'~ (in kT.Å^{-2}) 
#   - the second term is 2 * (U_osc / kE') / N * 100    (unit: Å^2/particle because we have multiplied by 100})

paste integral.dat pesos.dat > calcula.dat
# File calcula.dat:
#   - the first term ($1) is 1/2*kE'~ (in kT.Å^{-2})
#   - the second term ($2) is 2 * (U_osc / kE') / N * 100
#   - the third term ($3) is the weight w_i~

# Compute the Delta A_2 term.
# The \sum[msd*(k'*exp(c))*w], where msd is the mean squere displament and w the Gaussian quadrature weight of k'
awk -v const=$cexp '{s+=($2*($1+const))*$3} END {print s*(-1)}' calcula.dat > final_value_DA2.txt
read Da2 < final_value_DA2.txt

echo "Delta A_2 / NkT =" $Da2

rm pesos.dat calcula.dat

echo "Finished at :"
date
