from math import *
from scipy.constants import Avogadro, Boltzmann, Planck, u
#u is the atomic mass unit

k_E = 448956.0     # Spring constant

sigma = 3.405  # LJ diameter in Angstrom
rho = 1.2
T = 12         # temperature

N = 768        # Nb of atoms
m = 39.948     # mass of an atom in atomic mass unit

beta = 1 / (Boltzmann * T)

# Version 1
lambda_E = k_E/2 *1000/Avogadro / 100    #k_E in kJ.mol^(-1).nm^(-2)  factor 100
#Thermal de Broglie wavelength
Lambda_T = Planck / sqrt(2*pi * m * u * Boltzmann * T) * 1e10    # in Angstrom
A0 = 3/2 * (1 - 1/N) *  log(beta * lambda_E * Lambda_T**2 / pi) + log(rho * Lambda_T**3/sigma**3) / N
print("A_0/(NkT) =", A0)

# Version 2: same, but calculating using SI units
lambda_E = k_E/2 *1000/Avogadro / 1e-18    #k_E in kJ.mol^(-1).nm^(-2) converti en J/m
Lambda_T = Planck / sqrt(2*pi * m * u * Boltzmann * T)    # in m
sigma = sigma * 1e-10
A0 = 3/2 * (1 - 1/N) *  log(beta * lambda_E * Lambda_T**2 / pi) + log(rho * Lambda_T**3/sigma**3) / N

print("A_0/(NkT) =", A0)

# Use assumptation that Lambda_T = sigma
Lambda_T = sigma
A0 = 3/2 * (1 - 1/N) *  log(beta * lambda_E * Lambda_T**2 / pi) + log(rho) / N
print("A_0/(NkT) when assuming that Lambda_T is replaced by sigma :", A0)


# From the original script by Aragones et al.
#See formula in the Supplementary Material of Aragones free energy of an atomic solid
#xlanda_e = Lambda_E is expressed in kJ/mol
#xlanda_e = k_E/2 *1000/Avogadro / (Boltzmann * T) / 100
#where k_E is the spring constant in kJ.mol^(-1).nm(^-2)
#xlande_e = 448956/2 *1000/Avogadro / (Boltzmann * 240) / 100
#         = 1124.9374048033774, see below
