#!/usr/bin/env python
import numpy as np
import matplotlib.pyplot as plt
import os
import sys 
from math import *
import scipy
import pandas as pd
import shutil
import subprocess
from scipy.constants import N_A, k
from pymbar.timeseries import detectEquilibration


# Temperature
T = 0.1

# Energy
J_to_kT = 1/(k*T)
kT_to_J = k*T

# Pressure
Pa_to_bar = 1e-5
bar_to_atm = 0.986923
Pa_to_katm = Pa_to_bar*bar_to_atm/float(1000)

# Volume
A3_to_m3 = 1e-30

to_reduct =k/(A3_to_m3)
reduct_to_katm =Pa_to_katm*to_reduct


def checkIfDat(files):
    for file in files:     
        #if (os.path.exists(file) == False):
        command = "strip_yaml.sh "+file[:-4]
        os.system(command) 
        

def getPrelimResults(rep,phases):
    """
        - rep : str, directory where LSMC simulations for both phases stored
        - phases : array of str, for instance for hcp/ and fcc/ phases=["hcp","fcc"]
    
    """
    files = "orderparam.dat"

    os.chdir(rep+phases[0])
    checkIfDat(files)

    step = np.loadtxt("orderparam.dat")[:,0]
    order1 = np.loadtxt("orderparam.dat")[:,1]

    os.chdir(rep+phases[1])
    checkIfDat(files)

    order2 = np.loadtxt("orderparam.dat")[:,1] 
    
    ########## Plot charts
    plt.figure()
    
    plt.scatter(step,order1,marker='+',label=phases[0])
    plt.scatter(step,order2,marker='x',label=phases[1])
    plt.legend()
    plt.xlabel("MC moves")
    plt.ylabel("Order parameter")
    plt.grid()
    #plt.savefig("Orderparam.pdf")
    plt.show()

 
 
def biasLoop_order(rep,arrayT):   
    os.chdir(rep)
    
    for T in arrayT : 
        # For each T we display the bias function along with the probability density which is stored with combine
        os.chdir(f"Temp_{T}/")
        
        print(f"Bias for T = {T}")
        #!mergetrans_tri replica_*/TMATRX.000
        #!combine.sh
        getBiasResults("combine","FEDDAT.000_001",TM=True)
        #print(os.getcwd())
        bias = calc_dG_from_Bias("FEDDAT.000_001")
        print(f"deltaG : {bias} kT")
        print("\n")
        
        os.chdir("../..")
        
        
def getBiasDat(rep,T):
    os.chdir(rep)
    height = []
    width = []          
    
    for Ti in T:
        os.chdir(f"Temp_{Ti}")
        order = np.loadtxt("combine/FEDDAT.000_001")[:,0]
        bias = np.loadtxt("combine/FEDDAT.000_001")[:,1]

        # Index where the order parameter changes sign
        index_transition = np.searchsorted(order, 0.0) 
        min_phase1 = np.min(bias[:index_transition])
        index_min_phase1 = np.argmax( bias == min_phase1)
        min_phase2 = np.min(bias[index_transition:])
        index_min_phase2 = np.argmax( bias == min_phase2)
        
        widthPeak = order[index_min_phase2]-order[index_min_phase1]
        biasPeak = np.max(bias[index_min_phase1:index_min_phase2])
        
        width.append(widthPeak)
        height.append(biasPeak)
        
        os.chdir("../")
    
    return height, width
    
    
    
def exploit_prod(dirpath,rep,title1,title2,fed_file="FEDDAT.000_001",title=" ",svg=False,n=1):
    os.chdir(dirpath+rep)
    order = np.loadtxt(fed_file)[:,0]
    histo = np.loadtxt(fed_file)[:,2]
    
    fig, ax = plt.subplots(1,2,figsize=(8, 4))
    if (title != " "):
        fig.suptitle(title, fontsize=16)
    ax[0].set_title(title1)
    ax[0].plot(order,histo)
    ax[0].set(xlabel="Order parameters",ylabel="Visits")
    ax[0].grid()
    
    if (os.path.exists("orderparam.dat") == False):
        command = "strip_yaml.sh orderparam"
        os.system(command) 
    
    step = np.loadtxt("orderparam.dat")[:,0]
    order2 = np.loadtxt("orderparam.dat")[:,1]

    ax[1].set_title(title2)
    ax[1].scatter(step[::n],order2[::n],s=1)
    ax[1].set(xlabel="MC step",ylabel="Order prarameter")
    ax[1].grid()
    fig.tight_layout()
    
    if (svg is True):
        plt.savefig("Results.svg")
    else:
        plt.savefig("Results.pdf")
    plt.show()
    
    return order,histo
    
    

def count_transition(dirpath,rep,folder):
    command = "cd " +dirpath+rep+folder
    os.system(command) 
    
    command = "strip_yaml.sh psmcactive"
    os.system(command) 
    
    
    arr = np.loadtxt('psmcactive.dat')
    step = arr[1,0]-arr[0,0]
    arr = arr[arr[:,1] == 2]
    print(len(arr))
    
    transition = 0
    for i in range(0,len(arr)-1):
        delta = arr[i+1,0]-arr[i,0]
        if (delta  > step):
            transition += 1
    
    print(f"transition counted : {transition}")
    return transition
        
        
        
def prodAnalyis(currentP,P0,T,bins,N,Nstep,Norder=100):
    os.chdir(currentP)
    
    rep = ["/NPT_1","/NPT_2"]
    
    P = np.zeros(len(T))
    deltaG = np.zeros(len(T))
    deltaV = np.zeros(len(T))
    std_dV = np.zeros(len(T))
    meanV_2 = np.zeros( (len(T),2) )
    sigV_2 = np.zeros( (len(T),2) )
    transition = np.zeros(len(T))
    
    stdB_dG = np.zeros(len(T))
    avB_dG = np.zeros(len(T))
    stdBloc_dG = np.zeros(len(T))
    avBloc_dG = np.zeros(len(T))
    
    stdB_P = np.zeros(len(T))
    stdBloc_P = np.zeros(len(T))

    for i in range(len(T)):
        # First, we retrieve the histogram and the order paramter variation
        folder = f"Temp_{T[i]}/"
        P0_i = round(P0[i],3)
        #print(f"Folder {folder} : P = {P0_i} katm")
        title = f"Results hcp-fcc transition : ({T[i]} K, {P0_i} katm),\n {bins[i]} bins {Nstep[i]} MC steps, {N} atoms"
        exploit_prod(currentP,folder,"Visits histogram","Order parameter variation",title=title,n=Norder)
        transition[i] = count_transition(currentP,"",folder)

        # We then get Bias function 
        deltaG[i] = dG_from_YAML("YAMLDATA.000",1.,Nstep[i])
        print(f"deltaG = {deltaG[i]} kT at T = {T[i]} K")
        
        # Bias at the end of the production simulation BIAS CHART
        biasP = np.loadtxt("FEDDAT.000_001")[:,1]
        orderP = np.loadtxt("FEDDAT.000_001")[:,0]

        plt.figure()
        plt.plot(orderP,biasP)
        plt.grid()
        plt.savefig(f"bias_prod_{T[i]}.pdf")
        plt.show()
        
        # Unbiased probability distribution : technically its the same value (gotten with dG_from_YAML) bit we get the Prob.pdf chart
        title = "Visits histogram of the hcp-fcc transition"
        deltaG_bis = getDeltaG(".",Nstep[i],title,plot=True)
        print(f"deltaG = {deltaG_bis} kT")
        print("\n")
        
        # Now, we get DeltaV still keeping Vhcp and Vfcc with their uncertainties       
        deltaV[i],std_dV[i],meanV_2[i],sigV_2[i]=getDeltaV(currentP+folder,rep)
        print(f"Temp {T[i]} : deltaV = {deltaV[i]} , sigDeltaV = {std_dV[i]}, deltaG = {deltaG[i]}")
        
        
        # Getting uncertainties by bootstrap (10000 Resamples) and block analysis (10 blocs) for dG
        stdB_dG[i], avB_dG[i] = bootstrap_deltaG(f"{currentP}/Temp_{T[i]}/YAMLDATA.000",1,Nstep[i],10000)
        print(f"deltaG boot : {avB_dG[i]} \t +/- {stdB_dG[i]} \t, deltaG = {deltaG[i]}")
        avBloc_dG[i], stdBloc_dG[i] = block_dG(f"{currentP}/Temp_{T[i]}/YAMLDATA.000",1,float(Nstep[i]),10) 
        print(f"deltaG bloc : {avBloc_dG[i]} \t +/- {stdBloc_dG[i]} \t, deltaG = {deltaG[i]}")
        
        
        # Getting the new pressure
        P[i] = getNewPressure(P0[i],deltaG[i],deltaV[i],T[i])
        # Getting uncertainties by bootstrap and block analysis for P 
        stdB_P[i] = Pa_to_katm * get_std_P(deltaG[i],stdB_dG[i],deltaV[i],std_dV[i],T[i])
        print(f"Bootstrap : Pnew = {P[i]} +/- {stdB_P[i]} at T = {T[i]} K")
        stdBloc_P[i] = Pa_to_katm * get_std_P(deltaG[i],stdBloc_dG[i],deltaV[i],std_dV[i],T[i])
        print(f"Bloc : Pnew = {P[i]} +/- {stdBloc_P[i]} at T = {T[i]} K \n")
        
        os.chdir("..")
    
    rho_hcp = N/meanV_2[:,0]    
    rho_fcc = N/meanV_2[:,1]
        
    data = np.zeros((len(T),14))
    data[:,0] = T
    data[:,1] = P
    data[:,2] = deltaV
    data[:,3] = deltaG
    data[:,4] = std_dV
    data[:,5] = rho_hcp
    data[:,6] = rho_fcc
    data[:,7] = transition
    data[:,8] = stdB_dG
    data[:,9] = avB_dG
    data[:,10] = stdBloc_dG
    data[:,11] = avBloc_dG
    data[:,12] = stdB_P
    data[:,13] = stdBloc_P
    
    return data
    

def getBiasResults(rep,fed_file,TM=False):
    os.chdir(rep)
    order = np.loadtxt(fed_file)[:,0]
    bias = np.loadtxt(fed_file)[:,1]
    hist = np.loadtxt(fed_file)[:,2]
    
    ################################## BIAS PLOT
    plt.figure()
    plt.plot(order,bias,marker='+')
    plt.xlabel("Order parameter (kT)")
    plt.ylabel("Bias (kT)")
    plt.grid()
    #plt.savefig("Bias.pdf")
    plt.show()

    
    ################################## VISITS HISTOGRAM PLOT
    if (not TM):
        plt.figure()
        plt.plot(order,hist,marker='+')
        plt.xlabel("Order parameter (kT)")
        plt.ylabel("Visits")
        plt.grid()
        #plt.savefig("Visits.pdf")
        plt.show()
    
        ############################## ORDERPARAM PLOT
        checkIfDat(["orderparam.dat"])
        step = np.loadtxt("orderparam.dat")[:,0]
        param = np.loadtxt("orderparam.dat")[:,1]
        
        plt.figure()
        plt.scatter(order,hist,marker='x')
        plt.xlabel("MC moves")
        plt.ylabel("Order parameter")
        plt.grid()
        #plt.savefig("Order_parameter.pdf")

    
############################################################### DELTAG
    
def dG_from_YAML(YAMLfile,tmin,tmax):
    #print(os.getcwd())
    data = pd.read_csv(YAMLfile,sep=':',low_memory=False)
    data = np.array(data)
    data[:,0] = [dat.strip() for dat in data[:,0]]
    
    itime = np.where(data[:,0]=='timestamp')[0]
    ibias = np.where(data[:,0]=='bias')[0]
    iPSMC = np.where(data[:,0]=='psmcactive')[0]
    
    time = data[itime,1].astype(np.float64)
    bias = data[ibias,1].astype(np.float64)
    PSMC = data[iPSMC,1].astype(np.float64)
    
    iMin = np.where(time>=tmin)[0][0]
    iMax = np.where(time<=tmax)[0][-1]
                    

    iPhase1 = np.where(PSMC[iMin:iMax+1]==1)[0]
    iPhase2 = np.where(PSMC[iMin:iMax+1]==2)[0]
    
    sum1 = np.sum( np.exp(bias[iPhase1]) )
    sum2 = np.sum( np.exp(bias[iPhase2]) ) 
    
    deltaG=-log(sum2/sum1)

    return deltaG
    

    
def calc_dG_from_Bias(FEDDATfile):
    """
    Compute the free energy difference, in units of kT, from the BIAS FUNCTION stored in a FEDDAT file.
    deltaG = -ln(probability phase 2 / probability phase 1) (in units of kT)
    """

    op, bias, _ = np.loadtxt(FEDDATfile, unpack=True)

    prob_bias = np.exp(-bias) # deduce the corresponding probability distribution

    deltaG = -np.log(np.sum(prob_bias[(op > 0)]) / np.sum(prob_bias[(op < 0)]))

    return deltaG
    
    
def calc_dG_from_Prod(rep,FEDDATfile):
    """
    Compute the free energy difference, in units of kT, from the visited states histogram stored in a FEDDAT file.

    The bias is unfolded to deduce the probability distribution of an unbiased simulation.
    deltaG = -ln(probability phase 2 / probability phase 1) (in units of kT)
    """
    os.chdir(rep)
    op, bias, hist = np.loadtxt(FEDDATfile, unpack=True)

    hist_unbiased = hist * np.exp(-bias) # This removes the bias of the production simulation
    prob_unbiased = hist_unbiased#/ np.max(hist_unbiased)

    
    deltaG = -np.log(np.sum(prob_unbiased[op > 0]) / np.sum(prob_unbiased[op < 0]))

    return deltaG
    

def getDeltaV(rep,dirs,plot=False):
    """
        Get the difference deltaV = <V2>-<V1> from the NPT simulations 
        Could be improved to make use of the uncertainties sigmaV1 and sigmaV2
        The means are computed using blocks.py with blocks of 100 values each
    """
    meanV = np.zeros(2)
    sigV = np.zeros(2) 
    
    for i in range( len(dirs) ):
        #print(os.getcwd())
        os.chdir(rep+dirs[i])
        command = "strip_yaml.sh volume"
        os.system(command) 
        
        command  = "blocks.py --col 2 --size 100 volume.dat"
        dataV = subprocess.Popen(command,shell=True,stdout=subprocess.PIPE,encoding='utf-8').stdout.readlines()
        print(dataV)
        #dataV = !blocks.py --col 2 --size 100 volume.dat #--start $N0
        ## The volume is stored using the format x = <x> +/- delta_x, last element of the list
        #print(dataV)
        dataV = dataV[-1].split()
        meanV[i] = float( dataV[0] )
        sigV[i] = float( dataV[1] )
        
        if (plot):
            x = np.loadtxt("volume.dat")[:,0]
            v = np.loadtxt("volume.dat")[:,1]
            
            plt.figure()
            plt.scatter(x,v,marker='x')
            plt.xlabel("MC moves")
            plt.ylabel("Volume")
            plt.grid()
            plt.show()   
        os.chdir('..')
            
    
    deltaV = meanV[1]-meanV[0]
    deltaSigV = sigV[1]+sigV[0]
    return deltaV,deltaSigV,meanV,sigV
    
    
def getDeltaG(rep,Nstep,title="Unbiased visits histogram",plot=False):
    os.chdir(rep)
    
    command = "unbiasedhist.sh"
    os.system(command)
    #! unbiasedhist.sh
    param = np.loadtxt("unbiasedhist.dat")[:,0]
    hist = np.loadtxt("unbiasedhist.dat")[:,1]
    
    if (plot):
        plt.figure()
        plt.scatter(param,hist,marker='x')
        plt.xlabel("Order parameter")
        plt.ylabel("Visits")
        plt.title(title)
        plt.grid()
        plt.savefig("Prob.pdf")
        plt.show()
        
    deltaG = dG_from_YAML("YAMLDATA.000",1.,Nstep)
    
    return deltaG
    

######################## PRESSURE
    
def getNewPressure(P0,deltaG0,deltaV0,T):
    """
        We compute the pressure P_i+1 from P_i, deltaG_i, deltaV_i. 
        T is the same for all iteration
        We make sure we use the right units to compute P_i+1 in katm.
        Maybe there is better choice of units to make.
        We use the convention : deltaX = X2-X1
    """
    kT_to_J = k*T
    print(f"kT = {kT_to_J}")
    
    pente = deltaV0*A3_to_m3
    deltaG0 *= kT_to_J
    # We have to convert P0 in Pa before computing Pnew
    P0 /= Pa_to_katm
    Pnew = P0 - deltaG0/pente
    Pnew *= Pa_to_katm
    
    return Pnew
    

def get_data_range(filename,begin,end,block):
    boundaries = np.linspace(begin,end,num=block+1)
    #print(boundaries)
    data = np.zeros(block)
    
    for i in range(0,block):
        data[i] = dG_from_YAML(filename,boundaries[i]+1,boundaries[i+1])
    
    return data   
    

def block_dG(YAMLfile,ti,tf,Nblock):        
    dG = get_data_range(YAMLfile,ti,tf,Nblock)
    # We get the mean deltaG from those blocks
    meanG = np.mean(dG)
    # We then have the standard deviation over those blocks
    stdG = np.std(dG)
    print(f"Mean with {Nblock} blocks : {meanG} +/- {stdG/sqrt(Nblock)}")  
    
    return meanG, stdG/sqrt(Nblock)       
    

def bootstrap_deltaG(YAMLfile,tmin,tmax,Nresample):
    data = pd.read_csv(YAMLfile,sep=':')
    data = np.array(data)
    data[:,0] = [dat.strip() for dat in data[:,0]]
    
    itime = np.where(data[:,0]=='timestamp')[0]
    ibias = np.where(data[:,0]=='bias')[0]
    iPSMC = np.where(data[:,0]=='psmcactive')[0]
    
    time = data[itime,1].astype(np.float64)
    bias = data[ibias,1].astype(np.float64)
    PSMC = data[iPSMC,1].astype(np.float64)
    
    iMin = np.where(time>=tmin)[0][0]
    iMax = np.where(time<=tmax)[0][-1]
    

    biasB = bias[iMin:iMax+1]
    PSMCB = PSMC[iMin:iMax+1]

    DeltaG = np.zeros(Nresample)
    for i in range(Nresample):
        idx = np.random.choice(len(biasB),len(biasB))
        biasT = biasB[idx]
        PSMCT = PSMCB[idx]
        
        i1 = np.where(PSMCT==1)[0]
        i2 = np.where(PSMCT==2)[0]  
        
        sum1 = np.sum( np.exp(biasT[i1]) )
        sum2 = np.sum( np.exp(biasT[i2]) ) 
        
        DeltaG[i] = -log(sum2/sum1)
        
    std = np.std(DeltaG)
    mean = np.mean(DeltaG)

    return std/sqrt(Nresample),mean  
    
    
   
def get_std_P(deltaG,sigDeltaG,deltaV,sigDeltaV,T):
    kT_to_J = k*T
    
    deltaG_SI = deltaG*kT_to_J
    sigDeltaG_SI = sigDeltaG*kT_to_J
    
    deltaV_SI = deltaV*A3_to_m3
    sigDeltaV_SI = sigDeltaV*A3_to_m3
    
    sigP = abs( sigDeltaG_SI/deltaV_SI ) + abs(deltaG_SI/np.square(deltaV_SI))*abs(sigDeltaV_SI) # Pessimistic estimation
    #sigP = np.sqrt( np.square(sigDeltaG/deltaG) + np.square(sigDeltaV/deltaV)  )                # deltaG and deltaV not from the same simulation
    
    return sigP #*Pa_to_katm


def createRepNPT(rep,sub,pressure):

    for i in range(0,len(pressure)):
        os.chdir(rep+sub)
        command = f"mkdir {pressure[i]}_katm"
        os.system(command)
        os.chdir(f"{pressure[i]}_katm")
        
        if (sub == "hcp"):
            shutil.copyfile(rep+"CONFIG_hcp","CONFIG")
        elif (sub == "fcc"):
            shutil.copyfile(rep+"CONFIG_fcc","CONFIG")
        
        shutil.copyfile(rep+"CONTROL","CONTROL")
        shutil.copyfile(rep+"FIELD","FIELD")

        command = f"sed -i '' -e 's/pressure .*/pressure {pressure[i]*reduct_to_katm}/g' CONTROL"
        os.system(command) 
        

def get_simfolder(rep,sub):
    file = '_sim_folders.txt'
    
    os.chdir(rep+sub)
    folders = next(os.walk('.'))[1]
    print(folders)
    
    with open(file, 'w') as f:
        f.write('\n'.join(folders))       


def getMeanVolume(rep,N):
    file = '_sim_folders.txt'
    os.chdir(rep)
    
    with open("_sim_folders.txt") as f:
        sim_folders = f.read().splitlines() 
        
    volMean = np.zeros(len(sim_folders))    
    volSig = np.zeros(len(sim_folders)) 
    tEquil = np.zeros(len(sim_folders)) 
    rho = np.zeros(len(sim_folders)) 
    
    i = 0
    
    for folder in sim_folders:
        os.chdir(rep+folder)
        v = np.loadtxt("volume.dat")[:,1]    
        t0,g,Neff_max = detectEquilibration(v)
        volMean[i] = np.mean(v[t0:])
        volSig[i] = np.std(v[t0:])
        tEquil[i] = t0
        rho[i] = N/volMean[i]
        
        #print(f"{folder} : volume : {volMean[i]} +/- {volSig[i]} after t0 : {t0}")
        i += 1
        
    os.chdir(rep)
    with open("results_volume.txt",'w') as f:
        f.write("#Folder     density     mean volume.       std for volume       t0 \n")
        for j in range(0,i-1):
            #print(sim_folders[j][:-5])
            f.write(f"{sim_folders[j][:-5]}\t {rho[j]}\t {volMean[j]}\t {volSig[j]}\t {tEquil[j]}\n")
            
            
            
def getSigRhoNew(T,P,sigP,deltaP,N):
    """
        T : array of Temperature
        P : array of Pressure in katm
        sigP : array of std on Pi in katm
        deltaP : array of interval around Pi - mostly sigPi or multiple, in katm
        N : atoms number
        return sigRho = sigP/dPdRho
    """
    executable =  "/Users/olivia.moro/Simulations/DL_MONTE-2/bin/DLMONTE-SRL.X"
    
    deltaRho = np.zeros(len(T))
    
    # We are in iterI/prod/ folder
    # We loop over T
    for i in range(len(T)):
        print(f"For Temp_{T[i]}")
        os.chdir(f"Temp_{T[i]}")
        # We create temp_a/ folder in which we run an NPT simulation at Ti and Pi-deltaPi
        # they need FIELD, CONFIG, CONTROL from the chosen phase : here NPT_1 (hcp) is fine
        # at coexistence we can use either of them
        command = "mkdir temp_a"
        os.system(command)
        command = "cp NPT_1/{FIELD,CONTROL,CONFIG} temp_a/"
        os.system(command)
        command = f"sed -i '' -e 's/pressure .*/pressure {P[i]-deltaP[i]}/g' temp_a/CONTROL"
        os.system(command)
        os.chdir("temp_a")
        command = f"caffeinate -i {executable}; strip_yaml.sh volume"
        os.system(command)

        command  = "blocks.py --col 2 --size 100 volume.dat"
        dataV = subprocess.Popen(command,shell=True,stdout=subprocess.PIPE,encoding='utf-8').stdout.readlines()
        print(dataV)
        #dataV = !blocks.py --col 2 --size 100 volume.dat #--start $N0
        ## The volume is stored using the format x = <x> +/- delta_x, last element of the list
        #print(dataV)
        dataV = dataV[-1].split()
        meanVA = float( dataV[0] )
        sigVA = float( dataV[1] )
        print(f"V = {meanVA} +/- {sigVA}, rho_a = {N/meanVA}")
        os.chdir("../")
        
        # We create temp_b/ folder in which we run an NPT simulation at Ti and Pi+deltaPi
        command = "mkdir temp_b"
        os.system(command)
        command = "cp NPT_1/{FIELD,CONTROL,CONFIG} temp_b/"
        os.system(command)
        command = f"sed -i '' -e 's/pressure .*/pressure {P[i]+deltaP[i]}/g' temp_b/CONTROL"
        os.system(command)
        os.chdir("temp_b")
        command = f"caffeinate -i {executable}; strip_yaml.sh volume"
        os.system(command)
    
        command  = "blocks.py --col 2 --size 100 volume.dat"
        dataV = subprocess.Popen(command,shell=True,stdout=subprocess.PIPE,encoding='utf-8').stdout.readlines()
        print(dataV)
        #dataV = !blocks.py --col 2 --size 100 volume.dat #--start $N0
        ## The volume is stored using the format x = <x> +/- delta_x, last element of the list
        #print(dataV)
        dataV = dataV[-1].split()
        meanVB = float( dataV[0] )
        sigVB = float( dataV[1] )
        print(f"V = {meanVB} +/- {sigVB}, rho_b = {N/meanVB}")
        os.chdir("../")
        
        deltaRho[i] = N*(1/meanVB-1/meanVA)
        print(f"deltaRho = {deltaRho[i]}")
        print("\n")
        
        os.chdir("../")
        
    dPdRho = 2*deltaP/deltaRho    
    sigRho = sigP/dPdRho
    print(f"sigRho = {sigRho} \n")
    
    return sigRho
    
    
def readSigRhoNew(T,P,sigP,deltaP,N):
    """
        T : array of Temperature
        P : array of Pressure in katm
        sigP : array of std on Pi in katm
        deltaP : array of interval around Pi - mostly sigPi or multiple, in katm
        N : atoms number
        return sigRho = sigP/dPdRho
    """
    executable =  "/Users/olivia.moro/Simulations/DL_MONTE-2/bin/DLMONTE-SRL.X"
    
    deltaRho = np.zeros(len(T))
    
    # We are in iterI/prod/ folder
    # We loop over T
    for i in range(len(T)):
        print(f"For Temp_{T[i]}")
        os.chdir(f"Temp_{T[i]}")
        # We access temp_a/ folder in which we have run an NPT simulation at Ti and Pi-deltaPi
        os.chdir("temp_a")
        command  = "blocks.py --col 2 --size 100 volume.dat"
        dataV = subprocess.Popen(command,shell=True,stdout=subprocess.PIPE,encoding='utf-8').stdout.readlines()

        dataV = dataV[-1].split()
        meanVA = float( dataV[0] )
        sigVA = float( dataV[1] )
        print(f"V = {meanVA} +/- {sigVA}, rho_a = {N/meanVA}")
        os.chdir("../")
        
        # We access temp_b/ folder in which we have run an NPT simulation at Ti and Pi+deltaPi
        os.chdir("temp_b")    
        command  = "blocks.py --col 2 --size 100 volume.dat"
        dataV = subprocess.Popen(command,shell=True,stdout=subprocess.PIPE,encoding='utf-8').stdout.readlines()
        
        dataV = dataV[-1].split()
        meanVB = float( dataV[0] )
        sigVB = float( dataV[1] )
        print(f"V = {meanVB} +/- {sigVB}, rho_b = {N/meanVB}")
        os.chdir("../")
        
        deltaRho[i] = N*(1/meanVB-1/meanVA)
        print(f"deltaRho = {deltaRho[i]}")
        print("\n")
        
        os.chdir("../")
        
    dPdRho = 2*deltaP/deltaRho    
    sigRho = sigP/dPdRho
    print(f"sigRho = {sigRho} \n")
    
    return sigRho
      
